@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 """
 mysolr.mysolr
@@ -9,44 +8,55 @@ operate with a Solr server.
 
 >>> from mysolr import Solr
 >>> solr = Solr('http://myserver:8080/solr')
->>> query_response = solr.search('q':'*:*', 'rows': 0, 'start': 0,
-                                'facet': 'true', 'facet.field': 'province')
+>>> query = {'q':'*:*', 'rows': 0, 'start': 0, 'facet': 'true', 
+             'facet.field': 'province'}
+>>> query_response = solr.search(**query)
 
 """
-import requests
-import json
 from mysolr_response import SolrResponse
+from urlparse import urljoin
+from xml.sax.saxutils import escape
+
+import json
+import requests
+
 
 class Solr:
     """Acts as an easy-to-use interface to Solr."""
 
-    def __init__(self, base_url='http://localhost:8080/solr'):
+    def __init__(self, base_url='http://localhost:8080/solr/'):
         """ Initializes a Solr object. Solr URL is a needed parameter.
         """
         self.base_url = base_url
-    
+
     def search(self, **kwargs):
         """Queries Solr with the given kwargs and returns a SolrResponse
         object.
 
         :param **kwargs: Dictionary containing any of the available Solr query
-                         parameters described in 
+                         parameters described in
                          http://wiki.apache.org/solr/CommonQueryParameters.
                          'q' is a mandatory parameter.
-        
+
         """
         assert 'q' in kwargs
         kwargs['wt'] = 'python'
-        response = requests.get('%s/select' % (self.base_url), params=kwargs)
+        # base_url must be end with /
+        if self.base_url[-1] != '/':
+            self.base_url += '/'
+        response = requests.get(urljoin(self.base_url, 'select'), params=kwargs)
         response.raise_for_status()
         response_object = eval(response.read())
-        return SolrResponse(response_object)
-    
+        solr_response = SolrResponse(response_object)
+        solr_response.url = response.url
+        return solr_response
+
     def update(self, documents, input_type='xml', commit=True):
         """Sends an update/add message to add the array of hashes(documents) to
         Solr.
 
-        :param documents: A list of solr-compatible documents to index.
+        :param documents: A list of solr-compatible documents to index. You
+                          should use unicode strings for text/string fields.
         :param input_type: The format which documents are sent. Remember that json
                            is not supported until version 3.
         :param commit: If True, sends a commit message after the operation is
@@ -62,7 +72,7 @@ class Solr:
             self._post_json(json.dumps(documents))
         if commit:
             self.commit()
-    
+
     def delete_by_key(self, identifier, commit=True):
         """Sends an ID delete message to Solr.
 
@@ -74,7 +84,7 @@ class Solr:
         self._post_xml(xml)
         if commit:
             self.commit()
-    
+
     def delete_by_query(self, query, commit=True):
         """Sends a query delete message to Solr.
 
@@ -86,11 +96,11 @@ class Solr:
         self._post_xml(xml)
         if commit:
             self.commit()
-    
+
     def commit(self, wait_flush=True,
                wait_searcher=True, expunge_deletes=False):
         """Sends a commit message to Solr.
-        
+
         :param wait_flush: Block until index changes are flushed to disk (default is
                            True).
         :param wait_searcher: Block until a new searcher is opened and registered
@@ -103,10 +113,10 @@ class Solr:
                                                                                    'true' if wait_searcher else 'false',
                                                                                    'true' if expunge_deletes else 'false')
         self._post_xml(xml)
-    
+
     def optimize(self, wait_flush=True, wait_searcher=True, max_segments=1):
         """Sends an optimize message to Solr.
-        
+
         :param wait_flush: Block until index changes are flushed to disk (default
                            is True)
         :param wait_searcher: Block until a new searcher is opened and registered as
@@ -119,30 +129,30 @@ class Solr:
                                                                                   'true' if wait_searcher else 'false',
                                                                                   max_segments)
         self._post_xml(xml)
-    
+
     def rollback(self):
         """Sends a rollback message to Solr server."""
         xml = '<rollback />'
         self._post_xml(xml)
-    
+
     def _post_xml(self, xml):
         """ Sends the xml to Solr server.
 
         :param xml: XML document to be posted.
         """
-        url = '%s/update' % (self.base_url)
+        url = urljoin(self.base_url, 'update')
         xml_data = xml.encode('utf-8')
         response = requests.post(url, data=xml_data,
                                  headers={'Content-type': 'text/xml; charset=utf-8',
                                           'Content-Length': "%s" % len(xml_data)})
         response.raise_for_status()
-    
+
     def _post_json(self, json_doc):
         """ Sends the json to Solr server.
 
         :param json_doc: JSON document to be posted.
         """
-        url = '%s/update/json' % (self.base_url)
+        url = urljoin(self.base_url, 'update/json')
         json_data = json_doc.encode('utf-8')
         response = requests.post(url, data=json_data,
                                  headers={'Content-type': 'application/json; charset=utf-8',
@@ -152,10 +162,10 @@ class Solr:
 def _get_add_xml(array_of_hash, overwrite=True):
     """ Creates add XML message to send to Solr based on the array of hashes
     (documents) provided.
-    
+
     :param overwrite: Newer documents will replace previously added documents
                       with the same uniqueKey (default is True)
-    
+
     """
     xml = '<add overwrite="%s">' % ('true' if overwrite else 'false')
     for doc_hash in array_of_hash:
@@ -163,8 +173,12 @@ def _get_add_xml(array_of_hash, overwrite=True):
         for key, value in doc_hash.items():
             if type(value) == type(list()):
                 for v in value:
+                    if isinstance(v, basestring):
+                        v = escape(v)
                     doc = '%s<field name="%s">%s</field>' % (doc, key, v)
             else:
+                if isinstance(value, basestring):
+                    value = escape(value)
                 doc = '%s<field name="%s">%s</field>' % (doc, key, value)
         doc = '%s</doc>' % (doc)
         xml = '%s%s' % (xml, doc)
