@@ -22,14 +22,28 @@ class SolrResponse(object):
         solr_response -- Python object result of search query
 
         """
+        #: Solr full response.
         self.raw_response = solr_response
+        #: Solr query URL
+        self.url = None
+        #: Response status.
         self.status = solr_response['responseHeader']['status']
+        #: Query time.
         self.qtime = solr_response['responseHeader']['QTime']
+        #: Number of results.
         self.total_results = solr_response['response']['numFound']
+        #: Offset.
         self.start = solr_response['response']['start']
+        #: Documents list.
         self.documents = solr_response['response']['docs']
+        #: Facets parsed as a dict.
+        self.facets = None
         if 'facet_counts' in solr_response:
             self.facets = parse_facets(solr_response['facet_counts'])
+        #: Shorcut to stats resuts
+        self.stats = None
+        if 'stats' in solr_response:
+            self.stats = solr_response['stats']['stats_fields']
 
     def __repr__(self):
         values = (self.status, self.qtime, self.total_results)
